@@ -60,16 +60,16 @@ package Dist::Zilla::Plugin::Manifest::Write;
 
 # PODNAME: Dist::Zilla::Plugin::Manifest::Write
 # ABSTRACT: Have annotated MANIFEST in your distribution
-
-use namespace::autoclean;
-
-BEGIN {
-    our $VERSION = '0.002'; # VERSION
-};
+our $VERSION = '0.003'; # VERSION
 
 use Moose;
+use namespace::autoclean;
 with 'Dist::Zilla::Role::FileGatherer';
 
+use Dist::Zilla::Role::File 5.023 ();
+    #   We do not consume the role but just require the specified version. Before this version
+    #   `_added_by` was a string, not arrayref.
+
 use Dist::Zilla::File::FromCode;
 use List::Util;
 use Data::Printer;
@@ -320,7 +320,7 @@ Dist::Zilla::Plugin::Manifest::Write - Have annotated MANIFEST in your distribut
 
 =head1 VERSION
 
-Version 0.002.
+Version 0.003.
 
 =head1 WHAT?
 
